import { Component, Input, ElementRef, Renderer } from '@angular/core';
import { ImageLoader } from "../../providers/image-loader";
import { ImageLoaderConfig } from "../../providers/image-loader-config";
export var ImgLoader = (function () {
    function ImgLoader(element, renderer, imageLoader, config) {
        // if any config item was not provided, it will be replaced by the global config
        this.element = element;
        this.renderer = renderer;
        this.imageLoader = imageLoader;
        this.config = config;
        /**
         * Indicates if the image is still loading
         * @type {boolean}
         */
        this.isLoading = true;
        if (!this.spinner && config.spinnerEnabled) {
            this.spinner = true;
        }
        if (!this.fallbackUrl) {
            this.fallbackUrl = config.fallbackUrl;
        }
        if (typeof this._useImg !== 'boolean') {
            this.useImg = config.useImg;
        }
        if (!this.width) {
            this.width = config.width;
        }
        if (!this.height) {
            this.height = config.height;
        }
        if (!this.display) {
            this.display = config.display;
        }
        if (!this.backgroundSize) {
            this.backgroundSize = config.backgroundSize;
        }
        if (!this.backgroundRepeat) {
            this.backgroundRepeat = config.backgroundRepeat;
        }
    }
    Object.defineProperty(ImgLoader.prototype, "useImg", {
        /**
         * Use <img> tag
         */
        set: function (val) {
            this._useImg = val !== false;
        },
        enumerable: true,
        configurable: true
    });
    ImgLoader.prototype.ngOnInit = function () {
        var _this = this;
        if (!this.imageUrl) {
            // image url was not passed
            // this can happen when [src] is set to a variable that turned out to be undefined
            // one example could be a list of users with their profile pictures
            // in this case, it would be useful to use the fallback image instead
            if (this.fallbackUrl) {
                // we're not going to cache the fallback image since it should be locally saved
                this.setImage(this.fallbackUrl);
            }
            // remove the spinner just in case there is no fallback image
            this.isLoading = false;
            return;
        }
        this.imageLoader.getImagePath(this.imageUrl)
            .then(function (imageUrl) { return _this.setImage(imageUrl); })
            .catch(function (error) { return _this.setImage(_this.fallbackUrl || _this.imageUrl); });
    };
    ImgLoader.prototype.setImage = function (imageUrl) {
        var element;
        this.isLoading = false;
        if (this._useImg) {
            // Using <img> tag
            this.renderer.createElement(this.element.nativeElement, 'img');
            element = this.element.nativeElement.getElementsByTagName('IMG')[0];
            this.renderer.setElementAttribute(element, 'src', imageUrl);
        }
        else {
            // Not using <img> tag
            element = this.element.nativeElement;
            if (this.display) {
                this.renderer.setElementStyle(element, 'display', this.display);
            }
            if (this.height) {
                this.renderer.setElementStyle(element, 'height', this.height);
            }
            if (this.width) {
                this.renderer.setElementStyle(element, 'width', this.width);
            }
            if (this.backgroundSize) {
                this.renderer.setElementStyle(element, 'background-size', this.backgroundSize);
            }
            if (this.backgroundRepeat) {
                this.renderer.setElementStyle(element, 'background-repeat', this.backgroundRepeat);
            }
            this.renderer.setElementStyle(element, 'background-image', 'url(\'' + imageUrl + '\')');
        }
    };
    ImgLoader.decorators = [
        { type: Component, args: [{
                    selector: 'img-loader',
                    template: '<image-loader-spinner *ngIf="spinner && isLoading"></image-loader-spinner>'
                },] },
    ];
    /** @nocollapse */
    ImgLoader.ctorParameters = [
        { type: ElementRef, },
        { type: Renderer, },
        { type: ImageLoader, },
        { type: ImageLoaderConfig, },
    ];
    ImgLoader.propDecorators = {
        'imageUrl': [{ type: Input, args: ['src',] },],
        'fallbackUrl': [{ type: Input, args: ['fallback',] },],
        'spinner': [{ type: Input },],
        'useImg': [{ type: Input },],
        'width': [{ type: Input },],
        'height': [{ type: Input },],
        'display': [{ type: Input },],
        'backgroundSize': [{ type: Input },],
        'backgroundRepeat': [{ type: Input },],
    };
    return ImgLoader;
}());
//# sourceMappingURL=img-loader.js.map