import { ImageLoaderConfig } from "./image-loader-config";
export declare class ImageLoader {
    private config;
    /**
     * Indicates if the cache service is ready.
     * When the cache service isn't ready, images are loaded via browser instead.
     * @type {boolean}
     */
    private isCacheReady;
    /**
     * Indicates if this service is initialized.
     * This service is initialized once all the setup is done.
     * @type {boolean}
     */
    private isInit;
    /**
     * Number of concurrent requests allowed
     * @type {number}
     */
    private concurrency;
    /**
     * Queue items
     * @type {Array}
     */
    private queue;
    private processing;
    constructor(config: ImageLoaderConfig);
    /**
     * Clears the cache
     */
    clearCache(): void;
    /**
     * Downloads an image via cordova-plugin-file-transfer
     * @param imageUrl {string} The remote URL of the image
     * @param localPath {string} The local path to store the image at
     * @returns {Promise<any>} Returns a promise that resolves when the download is complete, or rejects on error.
     */
    private downloadImage(imageUrl, localPath);
    /**
     * Gets the filesystem path of an image.
     * This will return the remote path if anything goes wrong or if the cache service isn't ready yet.
     * @param imageUrl {string} The remote URL of the image
     * @returns {Promise<string>} Returns a promise that will always resolve with an image URL
     */
    getImagePath(imageUrl: string): Promise<string>;
    /**
     * Add an item to the queue
     * @param imageUrl
     * @param resolve
     * @param reject
     */
    private addItemToQueue(imageUrl, resolve, reject);
    /**
     * Check if we can process more items in the queue
     * @returns {boolean}
     */
    private readonly canProcess;
    /**
     * Processes one item from the queue
     */
    private processQueue();
    /**
     * Initialize the cache service
     * @param replace {boolean} Whether to replace the cache directory if it already exists
     */
    private initCache(replace?);
    /**
     * Get the local path of a previously cached image if exists
     * @param url {string} The remote URL of the image
     * @returns {Promise<string>} Returns a promise that resolves with the local path if exists, or rejects if doesn't exist
     */
    private getCachedImagePath(url);
    /**
     * Throws a console error if debug mode is enabled
     * @param error {string} Error message
     */
    private throwError(error);
    /**
     * Throws a console warning if debug mode is enabled
     * @param error {string} Error message
     */
    private throwWarning(error);
    /**
     * Check if file plugin exists
     * @returns {boolean} returns a boolean that indicates whether the plugin exists
     */
    private readonly filePluginExists;
    /**
     * Check if the cache directory exists
     * @returns {Promise<boolean|FileError>} Returns a promise that resolves if exists, and rejects if it doesn't
     */
    private readonly cacheDirectoryExists;
    /**
     * Creates the cache directory
     * @param replace {boolean} override directory if exists
     * @returns {Promise<DirectoryEntry|FileError>} Returns a promise that resolves if the directory was created, and rejects on error
     */
    private createCacheDirectory(replace?);
    /**
     * Creates a unique file name out of the URL
     * @param url {string} URL of the file
     * @returns {string} Unique file name
     */
    private createFileName(url);
    /**
     * Converts a string to a unique 32-bit int
     * @param string {string} string to hash
     * @returns {number} 32-bit int
     */
    private hashString(string);
}
